@@ -7,18 +7,17 @@
 #   Toolkit.
 #
 # AUTHOR
-#   Andy Wardley   <abw@kfs.org>
+#   Andy Wardley   <abw@andywardley.com>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2000 Andy Wardley.  All Rights Reserved.
-#   Copyright (C) 1998-2000 Canon Research Centre Europe Ltd.
+#   Copyright (C) 1996-2002 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-#------------------------------------------------------------------------
-#
-#   $Id: Template.pm,v 2.40 2002/04/17 14:04:37 abw Exp $
+# REVISION
+#   $Id: Template.pm,v 2.60 2003/04/23 12:44:32 abw Exp $
 #
 #========================================================================
  
@@ -28,20 +27,24 @@ use base qw( Template::Base );
 require 5.005;
 
 use strict;
-use vars qw( $VERSION $AUTOLOAD $ERROR $DEBUG );
+use vars qw( $VERSION $AUTOLOAD $ERROR $DEBUG $BINMODE );
 use Template::Base;
 use Template::Config;
+use Template::Constants;
 use Template::Provider;  
 use Template::Service;
 use File::Basename;
 use File::Path;
-# use Template::Parser;    # autoloaded on demand
 
 ## This is the main version number for the Template Toolkit.
 ## It is extracted by ExtUtils::MakeMaker and inserted in various places.
-$VERSION     = '2.07';
+$VERSION     = '2.09';
 $ERROR       = '';
 $DEBUG       = 0;
+$BINMODE     = ($^O eq 'MSWin32') ? 1 : 0;
+
+# preload all modules if we're running under mod_perl
+Template::Config->preload() if $ENV{ MOD_PERL };
 
 
 #------------------------------------------------------------------------
@@ -67,7 +70,7 @@ sub process {
 
 	# send processed template to output stream, checking for error
 	return ($self->error($error))
-	    if ($error = &_output($outstream, $output));
+	    if ($error = &_output($outstream, $output, $BINMODE));
 
 	return 1;
     }
@@ -113,6 +116,20 @@ sub context {
 sub _init {
     my ($self, $config) = @_;
 
+    # convert any textual DEBUG args to numerical form
+    my $debug = $config->{ DEBUG };
+    $config->{ DEBUG } = Template::Constants::debug_flags($self, $debug)
+        || return if defined $debug && $debug !~ /^\d+$/;
+        
+    # prepare a namespace handler for any CONSTANTS definition
+    if (my $constants = $config->{ CONSTANTS }) {
+	my $ns  = $config->{ NAMESPACE } ||= { };
+	my $cns = $config->{ CONSTANTS_NAMESPACE } || 'constants';
+	$constants = Template::Config->constants($constants)
+	    || return $self->error(Template::Config->error);
+	$ns->{ $cns } = $constants;
+    }
+
     $self->{ SERVICE } = $config->{ SERVICE }
 	|| Template::Config->service($config)
 	|| return $self->error(Template::Config->error);
@@ -133,7 +150,7 @@ sub _output {
     my $reftype;
     my $error = 0;
     
-    # call a CODE referenc
+    # call a CODE reference
     if (($reftype = ref($where)) eq 'CODE') {
 	&$where($text);
     }
@@ -145,6 +162,10 @@ sub _output {
     elsif ($reftype eq 'SCALAR') {
 	$$where .= $text;
     }
+    # push onto ARRAY ref
+    elsif ($reftype eq 'ARRAY') {
+	push @$where, $text;
+    }
     # call the print() method on an object that implements the method
     # (e.g. IO::Handle, Apache::Request, etc)
     elsif (UNIVERSAL::can($where, 'print')) {
@@ -538,8 +559,7 @@ Directory into which output files can be written.
 
 =item DEBUG
 
-Flag which, when enabled, causes any access to an undefined variable
-to be raised as an 'undef' error.
+Enable debugging messages.
 
 =back
 
@@ -880,7 +900,7 @@ Ignored and deleted.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@kfs.orgE<gt>
+Andy Wardley E<lt>abw@andywardley.comE<gt>
 
 L<http://www.andywardley.com/|http://www.andywardley.com/>
 
@@ -889,7 +909,7 @@ L<http://www.andywardley.com/|http://www.andywardley.com/>
 
 =head1 VERSION
 
-Template Toolkit version 2.07, released on 17 April 2002.
+Template Toolkit version 2.09, released on 23 April 2003.
 
 =head1 COPYRIGHT
 
