@@ -18,7 +18,7 @@
 #
 #------------------------------------------------------------------------
 #
-#   $Id: Base.pm,v 2.55 2002/07/30 12:44:55 abw Exp $
+#   $Id: Base.pm,v 2.59 2002/11/04 19:45:53 abw Exp $
 #
 #========================================================================
  
@@ -28,8 +28,9 @@ require 5.004;
 
 use strict;
 use vars qw( $VERSION );
+use Template::Constants;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.55 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.59 $ =~ /(\d+)\.(\d+)/);
 
 
 #------------------------------------------------------------------------
@@ -65,7 +66,8 @@ sub new {
 
     my $self = bless {
 	map { ($_ => shift @args) } @$argnames,
-	_ERROR  => ''
+	_ERROR  => '',
+        DEBUG   => 0,
     }, $class;
 
     return $self->_init($cfg) ? $self : $class->error($self->error);
@@ -121,6 +123,21 @@ sub DEBUG {
     print STDERR "DEBUG: ", @_;
 }
 
+sub debug {
+    my $self = shift;
+    my $msg  = join('', @_);
+    my ($pkg, $file, $line) = caller();
+
+    unless ($msg =~ /\n$/) {
+	$msg .= ($self->{ DEBUG } & Template::Constants::DEBUG_CALLER)
+		 ? " at $file line $line\n"
+		 : "\n";
+    }
+
+    print STDERR "[$pkg] $msg";
+}
+
+
 1;
 
 __END__
@@ -143,7 +160,7 @@ Template::Base - Base class module implementing common functionality
 
 =head1 SYNOPSIS
 
-    package Template::MyModule;
+    package My::Module;
     use base qw( Template::Base );
 
     sub _init {
@@ -153,6 +170,11 @@ Template::Base - Base class module implementing common functionality
 	return $self;
     }
 
+    package main;
+
+    my $object = My::Module->new({ doodah => 'foobar' })
+        || die My::Module->error();
+
 =head1 DESCRIPTION
 
 Base class module which implements a constructor and error reporting 
@@ -170,20 +192,20 @@ is returned, or undef on error.  Any error message raised can be examined
 via the error() class method or directly via the package variable ERROR
 in the derived class.
 
-    my $module = Template::MyModule->new({ ... })
-        || die Template::MyModule->error(), "\n";
+    my $module = My::Module->new({ ... })
+        || die My::Module->error(), "\n";
 
-    my $module = Template::MyModule->new({ ... })
-        || die "constructor error: $Template::MyModule::ERROR\n";
+    my $module = My::Module->new({ ... })
+        || die "constructor error: $My::Module::ERROR\n";
 
-=head2 error($msg)
+=head2 error($msg, ...)
 
 May be called as an object method to get/set the internal _ERROR member
 or as a class method to get/set the $ERROR variable in the derived class's
 package.
 
-    my $module = Template::MyModule->new({ ... })
-        || die Template::MyModule->error(), "\n";
+    my $module = My::Module->new({ ... })
+        || die My::Module->error(), "\n";
 
     $module->do_something() 
 	|| die $module->error(), "\n";
@@ -192,18 +214,55 @@ When called with parameters (multiple params are concatenated), this
 method will set the relevant variable and return undef.  This is most
 often used within object methods to report errors to the caller.
 
-    package Template::MyModule;
-
-    ...
+    package My::Module;
 
     sub foobar {
 	my $self = shift;
-	...
+
+	# some other code...
+
 	return $self->error('some kind of error...')
 	    if $some_condition;
-	...
     }
 
+=head2 debug($msg, ...)
+
+Generates a debugging message by concatenating all arguments
+passed into a string and printing it to STDERR.  A prefix is
+added to indicate the module of the caller.
+
+    package My::Module;
+
+    sub foobar {
+	my $self = shift;
+
+	$self->debug('called foobar()');
+
+	# some other code...
+    }
+
+When the foobar() method is called, the following message
+is sent to STDERR:
+
+    [My::Module] called foobar()
+
+Objects can set an internal DEBUG value which the debug()
+method will examine.  If this value sets the relevant bits
+to indicate DEBUG_CALLER then the file and line number of
+the caller will be appened to the message.
+
+    use Template::Constants qw( :debug );
+
+    my $module = My::Module->new({
+        DEBUG => DEBUG_SERVICE | DEBUG_CONTEXT | DEBUG_CALLER,
+    });
+
+    $module->foobar();
+
+This generates an error message such as:
+
+    [My::Module] called foobar() at My/Module.pm line 6
+
 =head1 AUTHOR
 
 Andy Wardley E<lt>abw@andywardley.comE<gt>
@@ -215,8 +274,8 @@ L<http://www.andywardley.com/|http://www.andywardley.com/>
 
 =head1 VERSION
 
-2.54, distributed as part of the
-Template Toolkit version 2.08, released on 30 July 2002.
+2.59, distributed as part of the
+Template Toolkit version 2.09, released on 23 April 2003.
 
 =head1 COPYRIGHT
 
