@@ -31,7 +31,7 @@
 # 
 #----------------------------------------------------------------------------
 #
-# $Id: Parser.pm,v 2.66 2002/07/30 12:44:58 abw Exp $
+# $Id: Parser.pm,v 2.71 2003/03/17 22:51:47 abw Exp $
 #
 #============================================================================
 
@@ -54,7 +54,7 @@ use constant ACCEPT   => 1;
 use constant ERROR    => 2;
 use constant ABORT    => 3;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.66 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.71 $ =~ /(\d+)\.(\d+)/);
 $DEBUG   = 0 unless defined $DEBUG;
 $ERROR   = '';
 
@@ -108,7 +108,7 @@ $QUOTED_ESCAPES = {
 sub new {
     my $class  = shift;
     my $config = $_[0] && UNIVERSAL::isa($_[0], 'HASH') ? shift(@_) : { @_ };
-    my ($tagstyle, $start, $end, $defaults, $grammar, $hash, $key, $udef);
+    my ($tagstyle, $debug, $start, $end, $defaults, $grammar, $hash, $key, $udef);
 
     my $self = bless { 
 	START_TAG   => undef,
@@ -123,7 +123,6 @@ sub new {
 	GRAMMAR     => undef,
 	_ERROR      => '',
 	FACTORY     => 'Template::Directive',
-	DEBUG       => $DEBUG,
     }, $class;
 
     # update self with any relevant keys in config
@@ -132,6 +131,24 @@ sub new {
     }
     $self->{ FILEINFO } = [ ];
 
+    # DEBUG config item can be a bitmask
+    if (defined ($debug = $config->{ DEBUG })) {
+        $self->{ DEBUG } = $debug & ( Template::Constants::DEBUG_PARSER
+                                    | Template::Constants::DEBUG_FLAGS );
+        $self->{ DEBUG_DIRS } = $debug & Template::Constants::DEBUG_DIRS;
+    }
+    # package variable can be set to 1 to support previous behaviour
+    elsif ($DEBUG == 1) {
+        $self->{ DEBUG } = Template::Constants::DEBUG_PARSER;
+        $self->{ DEBUG_DIRS } = 0;
+    }
+    # otherwise let $DEBUG be a bitmask
+    else {
+        $self->{ DEBUG } = $DEBUG & ( Template::Constants::DEBUG_PARSER
+                                    | Template::Constants::DEBUG_FLAGS );
+        $self->{ DEBUG_DIRS } = $DEBUG & Template::Constants::DEBUG_DIRS;
+    }
+
     $grammar = $self->{ GRAMMAR } ||= do {
 	require Template::Grammar;
 	Template::Grammar->new();
@@ -228,7 +245,7 @@ sub parse {
     my ($self, $text, $info) = @_;
     my ($tokens, $block);
 
-    $info->{ DEBUG } = $self->{ DEBUG } 
+    $info->{ DEBUG } = $self->{ DEBUG_DIRS }
 	unless defined $info->{ DEBUG };
 
 #    print "info: { ", join(', ', map { "$_ => $info->{ $_ }" } keys %$info), " }\n";
@@ -252,8 +269,8 @@ sub parse {
 
     return undef unless $block;				    ## RETURN ##
 
-    print STDERR "compiled main template document block:\n$block\n"
-	if $DEBUG;
+    $self->debug("compiled main template document block:\n$block")
+	if $self->{ DEBUG } & Template::Constants::DEBUG_PARSER;
 
     return {
 	BLOCK     => $block,
@@ -401,7 +418,7 @@ sub interpolate_text {
 
    while ($text =~
            /
-           ( (?: \\. | [^\$] ){1,4000} ) # escaped or non-'$' character [$1]
+           ( (?: \\. | [^\$] ){1,3000} ) # escaped or non-'$' character [$1]
            |
 	   ( \$ (?:		    # embedded variable	           [$2]
 	     (?: \{ ([^\}]*) \} )   # ${ ... }                     [$3]
@@ -462,8 +479,6 @@ sub interpolate_text {
 sub tokenise_directive {
     my ($self, $text, $line) = @_;
     my ($token, $uctoken, $type, $lookup);
-#    my ($lextable, $anycase, $start, $end) = 
-#	@$self{ qw( LEXTABLE ANYCASE START_TAG END_TAG ) };
     my $lextable = $self->{ LEXTABLE };
     my $style    = $self->{ STYLE }->[-1];
     my ($anycase, $start, $end) = @$style{ qw( ANYCASE START_TAG END_TAG ) };
@@ -598,8 +613,8 @@ sub define_block {
     my $defblock = $self->{ DEFBLOCK } 
         || return undef;
 
-    print STDERR "compiled block '$name':\n$block\n"
-	if $DEBUG;
+    $self->debug("compiled block '$name':\n$block")
+	if $self->{ DEBUG } & Template::Constants::DEBUG_PARSER;
 
     $defblock->{ $name } = $block;
     
@@ -1311,6 +1326,54 @@ created and used automatically if a GRAMMAR item isn't specified.
 
 
 
+=item DEBUG
+
+The DEBUG option can be used to enable various debugging features
+of the Template::Parser module.  
+
+    use Template::Constants qw( :debug );
+
+    my $template = Template->new({
+	DEBUG => DEBUG_PARSER | DEBUG_DIRS,
+    });
+
+The DEBUG value can include any of the following.  Multiple values
+should be combined using the logical OR operator, '|'.
+
+=over 4
+
+=item DEBUG_PARSER
+
+This flag causes the L<Template::Parser|Template::Parser> to generate
+debugging messages that show the Perl code generated by parsing and
+compiling each template.
+
+=item DEBUG_DIRS
+
+This option causes the Template Toolkit to generate comments
+indicating the source file, line and original text of each directive
+in the template.  These comments are embedded in the template output
+using the format defined in the DEBUG_FORMAT configuration item, or a
+simple default format if unspecified.
+
+For example, the following template fragment:
+
+    
+    Hello World
+
+would generate this output:
+
+    ## input text line 1 :  ##
+    Hello 
+    ## input text line 2 : World ##
+    World
+
+
+=back
+
+
+
+
 =back
 
 =head2 parse($text)
@@ -1338,8 +1401,8 @@ L<http://www.andywardley.com/|http://www.andywardley.com/>
 
 =head1 VERSION
 
-2.65, distributed as part of the
-Template Toolkit version 2.08, released on 30 July 2002.
+2.71, distributed as part of the
+Template Toolkit version 2.09, released on 23 April 2003.
 
  
 
