@@ -19,7 +19,7 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: DBI.pm,v 2.49 2002/07/30 12:45:31 abw Exp $
+#   $Id: DBI.pm,v 2.53 2002/11/04 19:47:05 abw Exp $
 # 
 #==============================================================================
 
@@ -35,7 +35,7 @@ use DBI;
 use vars qw( $VERSION $DEBUG $QUERY $ITERATOR );
 use base qw( Template::Plugin );
 
-$VERSION  = sprintf("%d.%02d", q$Revision: 2.49 $ =~ /(\d+)\.(\d+)/);
+$VERSION  = sprintf("%d.%02d", q$Revision: 2.53 $ =~ /(\d+)\.(\d+)/);
 $DEBUG    = 0 unless defined $DEBUG;
 $QUERY    = 'Template::Plugin::DBI::Query';
 $ITERATOR = 'Template::Plugin::DBI::Iterator';
@@ -341,7 +341,7 @@ sub _throw {
     my $error = shift || die "DBI throw() called without an error string\n";
 
     # throw error as DBI exception
-    die Template::Exception->new('DBI', $error);
+    die (Template::Exception->new('DBI', $error));
 }
 
 
@@ -930,8 +930,8 @@ Andy Wardley, Craig Barratt, Dave Hodgkinson and Rafael Kitover.
 
 =head1 VERSION
 
-2.48, distributed as part of the
-Template Toolkit version 2.08, released on 30 July 2002.
+2.53, distributed as part of the
+Template Toolkit version 2.09, released on 23 April 2003.
 
 
 
