@@ -16,7 +16,7 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: File.pm,v 2.52 2002/07/30 12:45:32 abw Exp $
+#   $Id: File.pm,v 2.56 2002/11/04 19:47:10 abw Exp $
 #
 #============================================================================
 
@@ -34,7 +34,7 @@ use vars qw( $VERSION );
 use base qw( Template::Plugin );
 use vars qw( @STAT_KEYS );
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.52 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.56 $ =~ /(\d+)\.(\d+)/);
 
 @STAT_KEYS = qw( dev ino mode nlink uid gid rdev size 
 		 atime mtime ctime blksize blocks );
@@ -140,7 +140,7 @@ sub present {
 
 sub throw {
     my ($self, $error) = @_;
-    die Template::Exception->new('File', $error);
+    die (Template::Exception->new('File', $error));
 }
 
 __END__
@@ -394,14 +394,14 @@ item.
 =head1 AUTHORS
 
 Michael Stevens E<lt>michael@etla.orgE<gt> wrote the original Directory plugin
-on which this is based.  Andy Wardley E<lt>abw@kfs.orgE<gt> split it into 
+on which this is based.  Andy Wardley E<lt>abw@wardley.orgE<gt> split it into 
 separate File and Directory plugins, added some extra code and documentation
 for VIEW support, and made a few other minor tweaks.
 
 =head1 VERSION
 
-2.51, distributed as part of the
-Template Toolkit version 2.08, released on 30 July 2002.
+2.56, distributed as part of the
+Template Toolkit version 2.09, released on 23 April 2003.
 
 
 
