@@ -12,18 +12,26 @@
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
+# REVISION
+#   $Id: Image.pm,v 1.4 2002/11/07 15:02:44 darren Exp $
+#
 #============================================================================
 
 package Template::Plugin::Image;
 
-use strict;
-use warnings;
-use base 'Template::Plugin';
-use Template::Exception;
-use File::Spec;
+require 5.004;
 
-our $VERSION = 1.21;
-our $AUTOLOAD;
+use strict;
+use Template::Exception;
+use Template::Plugin;
+use File::Spec;
+#use Image::Info;
+#use Image::Size;
+
+use base qw( Template::Plugin );
+use vars qw( $VERSION $AUTOLOAD );
+
+$VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 BEGIN {
     if (eval { require Image::Info; }) {
@@ -35,12 +43,7 @@ BEGIN {
             my @stuff = Image::Size::imgsize($file);
             return { "width"  => $stuff[0],
                      "height" => $stuff[1],
-                     "error"  =>
-                        # imgsize returns either a three letter file type
-                        # or an error message as third value
-                        (defined($stuff[2]) && length($stuff[2]) > 3
-                            ? $stuff[2]
-                            : undef),
+                     "error"  => $stuff[2]
                    };
         }
     }
@@ -77,19 +80,16 @@ sub new {
         $file = File::Spec->catfile($root, $name);
     }
     else {
-        $file = defined $config->{file} ? $config->{file} : $name;
+        $file = $name;
     }
 
     # Make a note of whether we are using Image::Size or
     # Image::Info -- at least for the test suite
     $type = $INC{"Image/Size.pm"} ? "Image::Size" : "Image::Info";
-
-    # set a default (empty) alt attribute for tag()
-    $config->{ alt } = '' unless defined $config->{ alt };
-
+        
     # do we want to check to see if file exists?
+
     bless { 
-        %$config,
         name => $name,
         file => $file,
         root => $root,
@@ -130,7 +130,6 @@ sub attr {
     return "width=\"$size->[0]\" height=\"$size->[1]\"";
 }
 
-
 #------------------------------------------------------------------------
 # modtime()
 #
@@ -145,7 +144,6 @@ sub modtime {
     return $self->{ modtime };
 }
 
-
 #------------------------------------------------------------------------
 # tag(\%options)
 #
@@ -156,18 +154,11 @@ sub tag {
     my $self = shift;
     my $options = ref $_[0] eq 'HASH' ? shift : { @_ };
 
-    my $tag = '<img src="' . $self->name() . '" ' . $self->attr();
- 
-    # XHTML spec says that the alt attribute is mandatory, so who
-    # are we to argue?
-
-    $options->{ alt } = $self->{ alt }
-        unless defined $options->{ alt };
+    my $tag = "<img src=\"$self->{ name }\" " . $self->attr();
 
     if (%$options) {
         while (my ($key, $val) = each %$options) {
-            my $escaped = escape( $val );
-            $tag .= qq[ $key="$escaped"];
+            $tag .= " $key=\"$val\"";
         }
     }
 
@@ -176,16 +167,6 @@ sub tag {
     return $tag;
 }
 
-sub escape {
-    my ($text) = @_;
-    for ($text) {
-        s/&/&amp;/g;
-        s/</&lt;/g;
-        s/>/&gt;/g;
-        s/"/&quot;/g;
-    }
-    $text;
-}
 
 sub throw {
     my ($self, $error) = @_;
@@ -204,6 +185,18 @@ sub AUTOLOAD {
 
 __END__
 
+
+#------------------------------------------------------------------------
+# IMPORTANT NOTE
+#   This documentation is generated automatically from source
+#   templates.  Any changes you make here may be lost.
+# 
+#   The 'docsrc' documentation source bundle is available for download
+#   from http://www.template-toolkit.org/docs.html and contains all
+#   the source templates, XML files, scripts, etc., from which the
+#   documentation for the Template Toolkit is built.
+#------------------------------------------------------------------------
+
 =head1 NAME
 
 Template::Plugin::Image - Plugin access to image sizes
@@ -219,10 +212,10 @@ Template::Plugin::Image - Plugin access to image sizes
 
 =head1 DESCRIPTION
 
-This plugin provides an interface to the L<Image::Info> or L<Image::Size>
+This plugin provides an interface to the Image::Info or Image::Size
 modules for determining the size of image files.
 
-You can specify the plugin name as either 'C<Image>' or 'C<image>'.  The
+You can specify the plugin name as either 'Image' or 'image'.  The
 plugin object created will then have the same name.  The file name of
 the image should be specified as a positional or named argument.
 
@@ -233,34 +226,13 @@ the image should be specified as a positional or named argument.
     [% USE image(name='baz.gif') %]
     [% USE Image name='pong.gif' %]
 
-A C<root> parameter can be used to specify the location of the image file:
-
-    [% USE Image(root='/path/to/root', name='images/home.png') %]
-    # image path: /path/to/root/images/home.png
-    # img src: images/home.png
-
-In cases where the image path and image url do not match up, specify the
-file name directly:
-
-    [% USE Image(file='/path/to/home.png', name='/images/home.png') %]
-
-The C<alt> parameter can be used to specify an alternate name for the
-image, for use in constructing an XHTML element (see the C<tag()> method
-below).
-
-    [% USE Image('home.png', alt="Home") %]
-
-You can also provide an alternate name for an C<Image> plugin object.
+You can also provide an alternate name for an Image plugin object.
 
     [% USE img1 = image 'foo.gif' %]
     [% USE img2 = image 'bar.gif' %]
 
-The C<name> method returns the image file name.
-
-    [% img1.name %]     # foo.gif
-
-The C<width> and C<height> methods return the width and height of the
-image, respectively.  The C<size> method returns a reference to a 2
+The 'width' and 'height' methods return the width and height of the
+image, respectively.  The 'size' method returns a reference to a 2
 element list containing the width and height.
 
     [% USE image 'foo.gif' %]
@@ -268,14 +240,7 @@ element list containing the width and height.
     height: [% image.height %]
     size: [% image.size.join(', ') %]
 
-The C<modtime> method returns the modification time of the file in question,
-suitable for use with the L<Date|Template::Plugin::Date> plugin, for example:
-
-    [% USE image 'foo.gif' %]
-    [% USE date %]
-    [% date.format(image.modtime, "%B, %e %Y") %]
-
-The C<attr> method returns the height and width as HTML/XML attributes.
+The 'attr' method returns the height and width as HTML/XML attributes.
 
     [% USE image 'foo.gif' %]
     [% image.attr %]
@@ -284,37 +249,38 @@ Typical output:
 
     width="60" height="20"
 
-The C<tag> method returns a complete XHTML tag referencing the image.
+The 'tag' method returns a complete XHTML tag referencing the image.
 
     [% USE image 'foo.gif' %]
     [% image.tag %]
 
 Typical output:
 
-    <img src="foo.gif" width="60" height="20" alt="" />
+    <img src="foo.gif" width="60" height="20" />
 
 You can provide any additional attributes that should be added to the 
 XHTML tag.
 
+
     [% USE image 'foo.gif' %]
-    [% image.tag(class="logo" alt="Logo") %]
+    [% image.tag(border=0, class="logo") %]
 
 Typical output:
 
-    <img src="foo.gif" width="60" height="20" alt="Logo" class="logo" />
+    <img src="foo.gif" width="60" height="20" border="0" class="logo" />
 
-Note that the C<alt> attribute is mandatory in a strict XHTML C<img>
-element (even if it's empty) so it is always added even if you don't
-explicitly provide a value for it.  You can do so as an argument to 
-the C<tag> method, as shown in the previous example, or as an argument
+The 'modtime' method returns the ctime of the file in question, suitable
+for use with date.format:
 
-    [% USE image('foo.gif', alt='Logo') %]
+    [% USE image 'foo.gif' %]
+    [% USE date %]
+    [% date.format(image.modtime, "%B, %e %Y") %]
 
 =head1 CATCHING ERRORS
 
 If the image file cannot be found then the above methods will throw an
-C<Image> error.  You can enclose calls to these methods in a
-C<TRY...CATCH> block to catch any potential errors.
+'Image' error.  You can enclose calls to these methods in a
+TRY...CATCH block to catch any potential errors.
 
     [% TRY;
          image.width;
@@ -325,47 +291,50 @@ C<TRY...CATCH> block to catch any potential errors.
 
 =head1 USING Image::Info
 
-At run time, the plugin tries to load L<Image::Info> in preference to
-L<Image::Size>. If L<Image::Info> is found, then some additional methods are
-available, in addition to C<size>, C<width>, C<height>, C<attr>, and C<tag>.
-These additional methods are named after the elements that L<Image::Info>
-retrieves from the image itself. The types of methods available depend on the
-type of image (see L<Image::Info> for more details). These additional methods
-will always include the following:
+At run time, the plugin tries to load Image::Info in preference to
+Image::Size. If Image::Info is found, then some additional methods are
+available, in addition to 'size', 'width', 'height', 'attr', and 'tag'.
+These additional methods are named after the elements that Image::Info
+retrieves from the image itself; see L<Image::Info> for more details
+-- the types of methods available depend on the type of image.
+These additional methods will always include the following:
 
-=head2 file_media_type
+=over 4
+
+=item file_media_type
 
 This is the MIME type that is appropriate for the given file format.
-The corresponding value is a string like: "C<image/png>" or "C<image/jpeg>".
+The corresponding value is a string like: "image/png" or "image/jpeg".
 
-=head2 file_ext
+=item file_ext
 
 The is the suggested file name extention for a file of the given
 file format.  The value is a 3 letter, lowercase string like
-"C<png>", "C<jpg>".
+"png", "jpg".
 
-=head2 color_type
+
+=item color_type
 
 The value is a short string describing what kind of values the pixels
 encode.  The value can be one of the following:
 
-    Gray
-    GrayA
-    RGB
-    RGBA
-    CMYK
-    YCbCr
-    CIELab
+  Gray
+  GrayA
+  RGB
+  RGBA
+  CMYK
+  YCbCr
+  CIELab
 
-These names can also be prefixed by "C<Indexed->" if the image is
-composed of indexes into a palette.  Of these, only "C<Indexed-RGB>" is
+These names can also be prefixed by "Indexed-" if the image is
+composed of indexes into a palette.  Of these, only "Indexed-RGB" is
 likely to occur.
 
 (It is similar to the TIFF field PhotometricInterpretation, but this
 name was found to be too long, so we used the PNG inpired term
 instead.)
 
-=head2 resolution
+=item resolution
 
 The value of this field normally gives the physical size of the image
 on screen or paper. When the unit specifier is missing then this field
@@ -377,60 +346,65 @@ The syntax of this field is:
    <xres> "/" <yres> <unit>
    <xres> "/" <yres>
 
-The C<E<lt>resE<gt>>, C<E<lt>xresE<gt>> and C<E<lt>yresE<gt>> fields are
-numbers.  The C<E<lt>unitE<gt>> is a string like C<dpi>, C<dpm> or
+The E<lt>resE<gt>, E<lt>xresE<gt> and E<lt>yresE<gt> fields are
+numbers.  The E<lt>unitE<gt> is a string like C<dpi>, C<dpm> or
 C<dpcm> (denoting "dots per inch/cm/meter).
 
-=head2 SamplesPerPixel
+=item SamplesPerPixel
 
 This says how many channels there are in the image.  For some image
 formats this number might be higher than the number implied from the
 C<color_type>.
 
-=head2 BitsPerSample
+=item BitsPerSample
 
 This says how many bits are used to encode each of samples.  The value
 is a reference to an array containing numbers. The number of elements
 in the array should be the same as C<SamplesPerPixel>.
 
-=head2 Comment
+=item Comment
 
 Textual comments found in the file.  The value is a reference to an
 array if there are multiple comments found.
 
-=head2 Interlace
+=item Interlace
 
-If the image is interlaced, then this returns the interlace type.
+If the image is interlaced, then this tell which interlace method is
+used.
 
-=head2 Compression
+=item Compression
 
-This returns the name of the compression algorithm is used.
+This tell which compression algorithm is used.
 
-=head2 Gamma
+=item Gamma
 
-A number indicating the gamma curve of the image (e.g. 2.2)
+A number.
+
+
+=back
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
+Andy Wardley E<lt>abw@andywardley.comE<gt>
+
+L<http://www.andywardley.com/|http://www.andywardley.com/>
+
+
+
+
+=head1 VERSION
+
+1.04, distributed as part of the
+Template Toolkit version 2.09, released on 23 April 2003.
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1996-2002 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template::Plugin>, L<Image::Info>
-
-=cut
-
-# Local Variables:
-# mode: perl
-# perl-indent-level: 4
-# indent-tabs-mode: nil
-# End:
-#
-# vim: expandtab shiftwidth=4:
+L<Template::Plugin|Template::Plugin>
\ No newline at end of file
