@@ -19,7 +19,7 @@
 # 
 #----------------------------------------------------------------------------
 #
-# $Id: Service.pm,v 2.52 2002/04/17 14:04:40 abw Exp $
+# $Id: Service.pm,v 2.65 2002/11/04 19:46:04 abw Exp $
 #
 #============================================================================
 
@@ -33,8 +33,9 @@ use base qw( Template::Base );
 use Template::Base;
 use Template::Config;
 use Template::Exception;
+use Template::Constants;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.52 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.65 $ =~ /(\d+)\.(\d+)/);
 $DEBUG   = 0 unless defined $DEBUG;
 
 
@@ -59,6 +60,10 @@ sub process {
     my ($name, $output, $procout, $error);
     $output = '';
 
+    $self->debug("process($template, ", 
+                 defined $params ? $params : '<no params>',
+                 ')') if $self->{ DEBUG };
+
     $context->reset()
 	if $self->{ AUTO_RESET };
 
@@ -79,6 +84,7 @@ sub process {
 	# PRE_PROCESS
 	eval {
 	    foreach $name (@{ $self->{ PRE_PROCESS } }) {
+                $self->debug("PRE_PROCESS: $name") if $self->{ DEBUG };
 		$output .= $context->process($name);
 	    }
 	};
@@ -87,6 +93,7 @@ sub process {
 	# PROCESS
 	eval {
 	    foreach $name (@{ $self->{ PROCESS } || [ $template ] }) {
+                $self->debug("PROCESS: $name") if $self->{ DEBUG };
 		$procout .= $context->process($name);
 	    }
 	};
@@ -99,6 +106,7 @@ sub process {
 	# POST_PROCESS
 	eval {
 	    foreach $name (@{ $self->{ POST_PROCESS } }) {
+                $self->debug("POST_PROCESS: $name") if $self->{ DEBUG };
 		$output .= $context->process($name);
 	    }
 	};
@@ -142,7 +150,7 @@ sub _init {
     # by splitting on non-word characters
     foreach $item (qw( PRE_PROCESS PROCESS POST_PROCESS )) {
 	$data = $config->{ $item };
-	next unless defined $data;
+        $self->{ $item } = [ ], next unless (defined $data);
 	$data = [ split($delim, $data || '') ]
 	    unless ref $data eq 'ARRAY';
         $self->{ $item } = $data;
@@ -154,6 +162,8 @@ sub _init {
     $self->{ ERROR      } = $config->{ ERROR } || $config->{ ERRORS };
     $self->{ AUTO_RESET } = defined $config->{ AUTO_RESET }
 			  ? $config->{ AUTO_RESET } : 1;
+    $self->{ DEBUG      } = ( $config->{ DEBUG } || 0 )
+                            & Template::Constants::DEBUG_SERVICE;
 
     $context = $self->{ CONTEXT } = $config->{ CONTEXT }
         || Template::Config->context($config)
@@ -196,9 +206,11 @@ sub _recover {
     if (ref $handlers eq 'HASH') {
 	if ($hkey = $$error->select_handler(keys %$handlers)) {
 	    $handler = $handlers->{ $hkey };
+            $self->debug("using error handler for $hkey") if $self->{ DEBUG };
 	}
 	elsif ($handler = $handlers->{ default }) {
 	    # use default handler
+            $self->debug("using default error handler") if $self->{ DEBUG };
 	}
 	else {
 	    return undef;					## RETURN
@@ -206,6 +218,7 @@ sub _recover {
     }
     else {
 	$handler = $handlers;
+        $self->debug("using default error handler") if $self->{ DEBUG };
     }
 
     eval { $handler = $context->template($handler) };
@@ -634,7 +647,7 @@ or by calling the throw() method on the current Template::Context object,
 
 or from Perl code by calling die() with a Template::Exception object,
 
-    die Template::Exception->new('user.denied', 'Invalid User ID');
+    die (Template::Exception->new('user.denied', 'Invalid User ID'));
 
 or by simply calling die() with an error string.  This is
 automagically caught and converted to an  exception of 'undef'
@@ -669,6 +682,21 @@ is enabled (default), or if the Template::Context reset() method is called.
 
 
 
+=item DEBUG
+
+The DEBUG option can be used to enable debugging messages from the
+Template::Service module by setting it to include the DEBUG_SERVICE
+value.
+
+    use Template::Constants qw( :debug );
+
+    my $template = Template->new({
+	DEBUG => DEBUG_SERVICE,
+    });
+
+
+
+
 =back
 
 =head2 process($input, \%replace)
@@ -701,7 +729,7 @@ Returns the most recent error message.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@kfs.orgE<gt>
+Andy Wardley E<lt>abw@andywardley.comE<gt>
 
 L<http://www.andywardley.com/|http://www.andywardley.com/>
 
@@ -710,8 +738,8 @@ L<http://www.andywardley.com/|http://www.andywardley.com/>
 
 =head1 VERSION
 
-2.50, distributed as part of the
-Template Toolkit version 2.07, released on 17 April 2002.
+2.67, distributed as part of the
+Template Toolkit version 2.09, released on 23 April 2003.
 
 =head1 COPYRIGHT
 
