@@ -20,7 +20,7 @@
 #
 #----------------------------------------------------------------------------
 #
-# $Id: Test.pm,v 2.48 2002/04/17 14:04:40 abw Exp $
+# $Id: Test.pm,v 2.60 2002/11/04 19:46:05 abw Exp $
 #
 #============================================================================
 
@@ -30,19 +30,21 @@ require 5.004;
 
 use strict;
 use vars qw( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS 
-	     $VERSION $DEBUG $EXTRA $PRESERVE 
+	     $VERSION $DEBUG $EXTRA $PRESERVE $REASON $NO_FLUSH
 	     $loaded %callsign);
 use Template qw( :template );
 use Exporter;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.48 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.60 $ =~ /(\d+)\.(\d+)/);
 $DEBUG   = 0;
 @ISA     = qw( Exporter );
-@EXPORT  = qw( ntests ok is match flush test_expect callsign banner );
+@EXPORT  = qw( ntests ok is match flush skip_all test_expect callsign banner );
 @EXPORT_OK = ( 'assert' );
 %EXPORT_TAGS = ( all => [ @EXPORT_OK, @EXPORT ] );
 $| = 1;
 
+$REASON   = 'not applicable on this platform';
+$NO_FLUSH = 0;
 $EXTRA    = 0;   # any extra tests to come after test_expect()
 $PRESERVE = 0	 # don't mangle newlines in output/expect
     unless defined $PRESERVE;
@@ -51,7 +53,7 @@ my @results = ();
 my ($ntests, $ok_count);
 *is = \&match;
 
-sub END {
+END {
     # ensure flush() is called to print any cached results 
     flush();
 }
@@ -74,7 +76,7 @@ sub ntests {
     # the grand total of tests
     $ntests += $EXTRA + scalar @results;	 
     $ok_count = 1;
-    print "1..$ntests\n";
+    print $ntests ? "1..$ntests\n" : "1..$ntests # skipped: $REASON\n";
     # flush cached results
     foreach my $pre_test (@results) {
 	ok(@$pre_test);
@@ -158,7 +160,21 @@ sub match {
 
 sub flush {
     ntests(0)
-	unless ($ok_count);
+	unless $ok_count || $NO_FLUSH;
+}
+
+
+#------------------------------------------------------------------------
+# skip_all($reason)
+#
+# Skip all tests, setting $REASON to contain any message passed.  Calls
+# exit(0) which triggers flush() which generates a "1..0 # $REASON"
+# string to keep to test harness happy.
+#------------------------------------------------------------------------
+
+sub skip_all {
+    $REASON = join('', @_);
+    exit(0);
 }
 
 
@@ -254,6 +270,14 @@ sub test_expect {
     # the remaining tests are defined in @tests...
     foreach $input (@tests) {
 	$count++;
+	my $name = '';
+
+	if ($input =~ s/^\s*-- name:? (.*?) --\s*\n//im) {
+	    $name = $1; 
+	}
+	else {
+	    $name = "template text $count";
+	}
 
 	# split input by a line like "-- expect --"
 	($input, $expect) = 
@@ -280,13 +304,13 @@ sub test_expect {
 	$tproc->process(\$input, $params, \$output) || do {
 	    warn "Template process failed: ", $tproc->error(), "\n";
 	    # report failure and automatically fail the expect match
-	    ok(0, "template test $count process FAILED: " . subtext($input));
+	    ok(0, "$name process FAILED: " . subtext($input));
 	    ok(0, '(obviously did not match expected)');
 	    next;
 	};
 
 	# processed OK
-	ok(1, "template test $count processed OK: " . subtext($input));
+	ok(1, "$name processed OK: " . subtext($input));
 
 	# another hack: if the '-- expect --' section starts with 
 	# '-- process --' then we process the expected output 
@@ -328,7 +352,7 @@ sub test_expect {
 		   $copyi, $copye, $copyo);
 	}
 
-	ok($match, $match ? "matched expected" : "did not match expected");
+	ok($match, $match ? "$name matched expected" : "$name did not match expected");
     };
 }
 
@@ -648,7 +672,7 @@ The line splitter may be a bit dumb, especially if it sees lines like
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@kfs.orgE<gt>
+Andy Wardley E<lt>abw@andywardley.comE<gt>
 
 L<http://www.andywardley.com/|http://www.andywardley.com/>
 
@@ -657,8 +681,8 @@ L<http://www.andywardley.com/|http://www.andywardley.com/>
 
 =head1 VERSION
 
-2.48, distributed as part of the
-Template Toolkit version 2.07, released on 17 April 2002.
+2.60, distributed as part of the
+Template Toolkit version 2.09, released on 23 April 2003.
 
 =head1 COPYRIGHT
 
